
# Slot: produces


holds between a material entity and a product that is generated through the intentional actions or functioning of the material entity

URI: [biolink:produces](https://w3id.org/biolink/vocab/produces)


## Domain and Range

[NamedThing](NamedThing.md) &#8594;  <sub>0..\*</sub> [NamedThing](NamedThing.md)

## Parents

 *  is_a: [related to](related_to.md)

## Children


## Used by


## Other properties

|  |  |  |
| --- | --- | --- |
| **In Subsets:** | | translator_minimal |
| **Exact Mappings:** | | RO:0003000 |
|  | | WIKIDATA_PROPERTY:P1056 |
|  | | SEMMEDDB:PRODUCES |
|  | | SEMMEDDB:produces |
| **Narrow Mappings:** | | NCIT:R29 |
|  | | SNOMED:has_process_output |
|  | | SNOMED:specimen_procedure_of |
| **Related Mappings:** | | GOREL:0001010 |

